@@ -212,10 +212,6 @@ class CallOp(Expression):
         funct = None
         try:
             funct = calculator.namespace.function(func_name, argspec_len)
-            # @functions take a ns as first arg.  TODO: Python functions possibly
-            # should too
-            if getattr(funct, '__name__', None) == '__call':
-                funct = partial(funct, calculator.namespace)
         except KeyError:
             try:
                 # DEVIATION: Fall back to single parameter
@@ -226,7 +222,12 @@ class CallOp(Expression):
                     log.error("Function not found: %s:%s", func_name, argspec_len, extra={'stack': True})
 
         if funct:
-            ret = funct(*args, **kwargs)
+            if getattr(funct, '_pyscss_needs_namespace', False):
+                # @functions and some Python functions take the namespace as an
+                # extra first argument
+                ret = funct(calculator.namespace, *args, **kwargs)
+            else:
+                ret = funct(*args, **kwargs)
             if not isinstance(ret, Value):
                 raise TypeError("Expected Sass type as return value, got %r" % (ret,))
             return ret
@@ -532,3 +533,33 @@ class AlphaFunctionLiteral(Expression):
             # TODO compress
             contents = child.render()
         return Function('opacity=' + contents, 'alpha', quotes=None)
+
+
+class TernaryOp(Expression):
+    """Sass implements this with a function:
+
+        prop: if(condition, true-value, false-value);
+
+    However, the second and third arguments are guaranteed not to be evaluated
+    unless necessary.  Functions always receive evaluated arguments, so this is
+    a syntactic construct in disguise.
+    """
+    def __repr__(self):
+        return '<%s(%r, %r, %r)>' % (
+            self.__class__.__name__,
+            self.condition,
+            self.true_expression,
+            self.false_expression,
+        )
+
+    def __init__(self, list_literal):
+        args = list_literal.items
+        if len(args) != 3:
+            raise SyntaxError("if() must have exactly 3 arguments")
+        self.condition, self.true_expression, self.false_expression = args
+
+    def evaluate(self, calculator, divide=False):
+        if self.condition.evaluate(calculator, divide=True):
+            return self.true_expression.evaluate(calculator, divide=True)
+        else:
+            return self.false_expression.evaluate(calculator, divide=True)
