@@ -250,8 +250,8 @@ def watch_sources(options):
                 dest_path = os.path.join(os.path.dirname(src_path), fname)
 
             print("Compiling %s => %s" % (src_path, dest_path))
-            dest_file = open(dest_path, 'w')
-            dest_file.write(self.css.compile(scss_file=src_path))
+            dest_file = open(dest_path, 'wb')
+            dest_file.write(self.css.compile(scss_file=src_path).encode('utf-8'))
 
         def on_moved(self, event):
             super(ScssEventHandler, self).on_moved(event)
@@ -348,6 +348,7 @@ class SassRepl(object):
                     self.compilation._at_options(self.calculator, rule, scope, block)
                     continue
                 elif code == '@import':
+                    # TODO this doesn't really work either since there's no path
                     self.compilation._at_import(self.calculator, rule, scope, block)
                     continue
                 elif code == '@include':
@@ -357,6 +358,7 @@ class SassRepl(object):
                     if code:
                         final_cont += code
                     if children:
+                        # TODO this almost certainly doesn't work, and is kind of goofy anyway since @mixin isn't supported
                         self.compilation.children.extendleft(children)
                         self.compilation.parse_children()
                         code = self.compilation._create_css(self.compilation.rules).rstrip('\n')
